Page 134 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 134

Home

    The Cuban leader that our State Department said "had
    to go" was Fulgencio Batista, whom they called a
    "corrupt dictator." It is strange that when tens of
    thousands of Cubans were being murdered and

    imprisoned by Castro, the State Department never found
    it in their vocabulary to call him a "corrupt dictator."

    The fact was, that in 1957 under Batista, Cuba had
    the highest standard of living in Latin America, 1957
    being Cuba's most prosperous year. Wages were high
    and the Cuban peso was at parity with the dollar. Even
    though he was not without some faults, Batista had built
    roads, schools, and hotels, and had attracted foreign
    investors. Castro put an end to this progress and made
    Cuba a giant prison camp.

    The methods used to establish a Communist

    dictatorship in Cuba were a replay of the methods used
    before. First a propaganda campaign was carried out
    against Bastista, then military arms were supplied to the
    revolutionaries. This was followed by an arms embargo
    against the Cuban government, and constant State
    Department pressure against Batista.

    The top men in the State Department at this time, who
    were members of the New York based Council on

    Foreign Relations were: Secretary of State John Foster
    Dulles, Under Secretary of State Christian Herter, and
    Deputy Under Secretary of State Robert Murphy. The
    leader of the CIA was CFR member Allen Dulles, and
    the man who occupied the White House was CFR

    129

    Babylon's War Against God